==> jc-1.4.0.tar.gz: soot/RadioScenePack.h <==
// public class soot.RadioScenePack

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 86700b06d7b70b0e soot_RadioScenePack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack

// header file dependencies
// @dep_header soot_ScenePack

#include "soot/ScenePack.h"

#ifndef _JC_soot_RadioScenePack_H_
#define _JC_soot_RadioScenePack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Transform$object;

// Typedefs
typedef struct _jc_soot_RadioScenePack$sub_refs	_jc_soot_RadioScenePack$sub_refs;
typedef struct _jc_soot_RadioScenePack$sub_nonrefs	_jc_soot_RadioScenePack$sub_nonrefs;
typedef struct _jc_soot_RadioScenePack$refs	_jc_soot_RadioScenePack$refs;
typedef struct _jc_soot_RadioScenePack$nonrefs	_jc_soot_RadioScenePack$nonrefs;
typedef struct _jc_soot_RadioScenePack$object	_jc_soot_RadioScenePack$object;

typedef const struct _jc_soot_RadioScenePack$vmethods	_jc_soot_RadioScenePack$vmethods;
typedef const struct _jc_soot_RadioScenePack$vtable	_jc_soot_RadioScenePack$vtable;
typedef const struct _jc_soot_RadioScenePack$vtype	_jc_soot_RadioScenePack$vtype;

// Constructors
extern void _jc_soot_RadioScenePack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_soot_RadioScenePack$method$add$2ce7b6f7bdda3730(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *);
extern void _jc_soot_RadioScenePack$method$checkEnabled$42d57dd014c7d69b(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *);
extern void _jc_soot_RadioScenePack$method$insertAfter$b9234295296f9b83(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_RadioScenePack$method$insertBefore$06bf7c7db00d0f75(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_RadioScenePack$method$internalApply$e44bdfd255a61742(_jc_env *, struct _jc_soot_RadioScenePack$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_RadioScenePack$method_info$add$2ce7b6f7bdda3730;
extern _jc_method _jc_soot_RadioScenePack$method_info$checkEnabled$42d57dd014c7d69b;
extern _jc_method _jc_soot_RadioScenePack$method_info$insertAfter$b9234295296f9b83;
extern _jc_method _jc_soot_RadioScenePack$method_info$insertBefore$06bf7c7db00d0f75;
extern _jc_method _jc_soot_RadioScenePack$method_info$internalApply$e44bdfd255a61742;

// Virtual methods structure
struct _jc_soot_RadioScenePack$vmethods {
	void	(*add$2ce7b6f7bdda3730)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *);
	void	(*checkEnabled$42d57dd014c7d69b)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *);
	void	(*insertAfter$b9234295296f9b83)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *);
	void	(*insertBefore$06bf7c7db00d0f75)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *);
	void	(*internalApply$e44bdfd255a61742)(_jc_env *, struct _jc_soot_RadioScenePack$object *);
};

// Vtable
struct _jc_soot_RadioScenePack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_ScenePack$vmethods	soot_ScenePack;
	_jc_soot_RadioScenePack$vmethods	soot_RadioScenePack;
};

// Vtype
struct _jc_soot_RadioScenePack$vtype {
	_jc_type			type;
	_jc_soot_RadioScenePack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_RadioScenePack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_RadioScenePack$refs {
    _jc_soot_RadioScenePack$sub_refs	soot_RadioScenePack;
    _jc_soot_ScenePack$sub_refs	soot_ScenePack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_RadioScenePack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_RadioScenePack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_ScenePack$sub_nonrefs	soot_ScenePack;
    _jc_soot_RadioScenePack$sub_nonrefs	soot_RadioScenePack;
};

// Object instance structure
struct _jc_soot_RadioScenePack$object {
	_jc_soot_RadioScenePack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_RadioScenePack$vtype	*vtype;
	_jc_soot_RadioScenePack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_RadioScenePack$vtype _jc_soot_RadioScenePack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_RadioScenePack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_RadioScenePack$class_object;

#endif	/* _JC_soot_RadioScenePack_H_ */

==> jc-1.4.6.tar.gz: soot/RadioScenePack.h <==
// public class soot.RadioScenePack

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 86700b06d7b70b0e soot_RadioScenePack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack

// header file dependencies
// @dep_header soot_ScenePack

#include "soot/ScenePack.h"

#ifndef _JC_soot_RadioScenePack_H_
#define _JC_soot_RadioScenePack_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Transform$object;

// Typedefs
typedef struct _jc_soot_RadioScenePack$sub_refs	_jc_soot_RadioScenePack$sub_refs;
typedef struct _jc_soot_RadioScenePack$sub_nonrefs	_jc_soot_RadioScenePack$sub_nonrefs;
typedef struct _jc_soot_RadioScenePack$refs	_jc_soot_RadioScenePack$refs;
typedef struct _jc_soot_RadioScenePack$nonrefs	_jc_soot_RadioScenePack$nonrefs;
typedef struct _jc_soot_RadioScenePack$object	_jc_soot_RadioScenePack$object;

typedef const struct _jc_soot_RadioScenePack$vmethods	_jc_soot_RadioScenePack$vmethods;
typedef const struct _jc_soot_RadioScenePack$vtable	_jc_soot_RadioScenePack$vtable;
typedef const struct _jc_soot_RadioScenePack$vtype	_jc_soot_RadioScenePack$vtype;

// Constructors
extern void _jc_soot_RadioScenePack$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_RadioScenePack$method$add$2ce7b6f7bdda3730(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *) _JC_JCNI_ATTR;
extern void _jc_soot_RadioScenePack$method$checkEnabled$42d57dd014c7d69b(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *) _JC_JCNI_ATTR;
extern void _jc_soot_RadioScenePack$method$insertAfter$b9234295296f9b83(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_RadioScenePack$method$insertBefore$06bf7c7db00d0f75(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_RadioScenePack$method$internalApply$e44bdfd255a61742(_jc_env *, struct _jc_soot_RadioScenePack$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_RadioScenePack$method_info$add$2ce7b6f7bdda3730;
extern _jc_method _jc_soot_RadioScenePack$method_info$checkEnabled$42d57dd014c7d69b;
extern _jc_method _jc_soot_RadioScenePack$method_info$insertAfter$b9234295296f9b83;
extern _jc_method _jc_soot_RadioScenePack$method_info$insertBefore$06bf7c7db00d0f75;
extern _jc_method _jc_soot_RadioScenePack$method_info$internalApply$e44bdfd255a61742;

// Virtual methods structure
struct _jc_soot_RadioScenePack$vmethods {
	void	(*add$2ce7b6f7bdda3730)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *) _JC_JCNI_ATTR;
	void	(*checkEnabled$42d57dd014c7d69b)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *) _JC_JCNI_ATTR;
	void	(*insertAfter$b9234295296f9b83)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*insertBefore$06bf7c7db00d0f75)(_jc_env *, struct _jc_soot_RadioScenePack$object *, struct _jc_soot_Transform$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*internalApply$e44bdfd255a61742)(_jc_env *, struct _jc_soot_RadioScenePack$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_RadioScenePack$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Pack$vmethods	soot_Pack;
	_jc_soot_ScenePack$vmethods	soot_ScenePack;
	_jc_soot_RadioScenePack$vmethods	soot_RadioScenePack;
};

// Vtype
struct _jc_soot_RadioScenePack$vtype {
	_jc_type			type;
	_jc_soot_RadioScenePack$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_RadioScenePack$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_RadioScenePack$refs {
    _jc_soot_RadioScenePack$sub_refs	soot_RadioScenePack;
    _jc_soot_ScenePack$sub_refs	soot_ScenePack;
    _jc_soot_Pack$sub_refs	soot_Pack;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_RadioScenePack$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_RadioScenePack$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Pack$sub_nonrefs	soot_Pack;
    _jc_soot_ScenePack$sub_nonrefs	soot_ScenePack;
    _jc_soot_RadioScenePack$sub_nonrefs	soot_RadioScenePack;
};

// Object instance structure
struct _jc_soot_RadioScenePack$object {
	_jc_soot_RadioScenePack$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_RadioScenePack$vtype	*vtype;
	_jc_soot_RadioScenePack$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_RadioScenePack$vtype _jc_soot_RadioScenePack$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_RadioScenePack, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_RadioScenePack$class_object;

#endif	/* _JC_soot_RadioScenePack_H_ */
